package com.fizz.business.service;

import java.util.List;
import com.fizz.business.domain.SetupTmBendforce;

/**
 * 光整机弯辊力Service接口
 * 
 * @author Joshi
 * @date 2025-09-26
 */
public interface ISetupTmBendforceService 
{
    /**
     * 查询光整机弯辊力
     * 
     * @param width 光整机弯辊力主键
     * @return 光整机弯辊力
     */
    public SetupTmBendforce selectSetupTmBendforceByWidth(Long width,Long rollForce);

    /**
     * 查询光整机弯辊力列表
     * 
     * @param setupTmBendforce 光整机弯辊力
     * @return 光整机弯辊力集合
     */
    public List<SetupTmBendforce> selectSetupTmBendforceList(SetupTmBendforce setupTmBendforce);

    /**
     * 新增光整机弯辊力
     * 
     * @param setupTmBendforce 光整机弯辊力
     * @return 结果
     */
    public int insertSetupTmBendforce(SetupTmBendforce setupTmBendforce);

    /**
     * 修改光整机弯辊力
     * 
     * @param setupTmBendforce 光整机弯辊力
     * @return 结果
     */
    public int updateSetupTmBendforce(SetupTmBendforce setupTmBendforce);

    /**
     * 批量删除光整机弯辊力
     * 
     * @param widths 需要删除的光整机弯辊力主键集合
     * @return 结果
     */
    public int deleteSetupTmBendforceByWidths(Long[] widths,Long[] rollForces);

    /**
     * 删除光整机弯辊力信息
     * 
     * @param width 光整机弯辊力主键
     * @return 结果
     */
    public int deleteSetupTmBendforceByWidth(Long width);
}
